from .._version import *
from .ads import ads
AllDockAreas = ads.AllDockAreas
BitwiseAnd = ads.BitwiseAnd
BitwiseOr = ads.BitwiseOr
BottomDockWidgetArea = ads.BottomDockWidgetArea
CDockAreaTabBar = ads.CDockAreaTabBar
CDockAreaTitleBar = ads.CDockAreaTitleBar
CDockAreaWidget = ads.CDockAreaWidget
CDockComponentsFactory = ads.CDockComponentsFactory
CDockContainerWidget = ads.CDockContainerWidget
CDockFocusController = ads.CDockFocusController
CDockManager = ads.CDockManager
CDockOverlay = ads.CDockOverlay
CDockOverlayCross = ads.CDockOverlayCross
CDockSplitter = ads.CDockSplitter
CDockWidget = ads.CDockWidget
CDockWidgetTab = ads.CDockWidgetTab
CDockingStateReader = ads.CDockingStateReader
CElidingLabel = ads.CElidingLabel
CFloatingDockContainer = ads.CFloatingDockContainer
CFloatingDragPreview = ads.CFloatingDragPreview
CIconProvider = ads.CIconProvider
CSpacerWidget = ads.CSpacerWidget
CTitleBarButton = ads.CTitleBarButton
CenterDockWidgetArea = ads.CenterDockWidgetArea
DockAreaCloseIcon = ads.DockAreaCloseIcon
DockAreaMenuIcon = ads.DockAreaMenuIcon
DockAreaUndockIcon = ads.DockAreaUndockIcon
DockWidgetArea = ads.DockWidgetArea
DockWidgetAreas = ads.DockWidgetAreas
DraggingFloatingWidget = ads.DraggingFloatingWidget
DraggingInactive = ads.DraggingInactive
DraggingMousePressed = ads.DraggingMousePressed
DraggingTab = ads.DraggingTab
IFloatingWidget = ads.IFloatingWidget
IconCount = ads.IconCount
InvalidDockWidgetArea = ads.InvalidDockWidgetArea
LeftDockWidgetArea = ads.LeftDockWidgetArea
NoDockWidgetArea = ads.NoDockWidgetArea
OuterDockAreas = ads.OuterDockAreas
RightDockWidgetArea = ads.RightDockWidgetArea
TabCloseIcon = ads.TabCloseIcon
TitleBarButton = ads.TitleBarButton
TitleBarButtonClose = ads.TitleBarButtonClose
TitleBarButtonTabsMenu = ads.TitleBarButtonTabsMenu
TitleBarButtonUndock = ads.TitleBarButtonUndock
TopDockWidgetArea = ads.TopDockWidgetArea
eBitwiseOperator = ads.eBitwiseOperator
eDragState = ads.eDragState
eIcon = ads.eIcon



# The PEP 484 type hints stub file for the ads module.
#
# Generated by SIP 4.19.18


import typing
import sip

from PyQt5 import QtWidgets
from PyQt5 import QtCore

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]

# Convenient aliases for complicated OpenGL types.
PYQT_OPENGL_ARRAY = typing.Union[typing.Sequence[int], typing.Sequence[float],
        sip.Buffer, None]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[typing.Sequence[int],
        typing.Sequence[float], sip.Buffer, int, None]



    class eBitwiseOperator(int): ...
    BitwiseAnd = ... # type: 'ads.eBitwiseOperator'
    BitwiseOr = ... # type: 'ads.eBitwiseOperator'

    class eIcon(int): ...
    TabCloseIcon = ... # type: 'ads.eIcon'
    DockAreaMenuIcon = ... # type: 'ads.eIcon'
    DockAreaUndockIcon = ... # type: 'ads.eIcon'
    DockAreaCloseIcon = ... # type: 'ads.eIcon'
    IconCount = ... # type: 'ads.eIcon'

    class eDragState(int): ...
    DraggingInactive = ... # type: 'ads.eDragState'
    DraggingMousePressed = ... # type: 'ads.eDragState'
    DraggingTab = ... # type: 'ads.eDragState'
    DraggingFloatingWidget = ... # type: 'ads.eDragState'

    class TitleBarButton(int): ...
    TitleBarButtonTabsMenu = ... # type: 'ads.TitleBarButton'
    TitleBarButtonUndock = ... # type: 'ads.TitleBarButton'
    TitleBarButtonClose = ... # type: 'ads.TitleBarButton'

    class DockWidgetArea(int): ...
    NoDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    LeftDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    RightDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    TopDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    BottomDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    CenterDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    InvalidDockWidgetArea = ... # type: 'ads.DockWidgetArea'
    OuterDockAreas = ... # type: 'ads.DockWidgetArea'
    AllDockAreas = ... # type: 'ads.DockWidgetArea'

    class DockWidgetAreas(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, f: typing.Union['ads.DockWidgetAreas', 'ads.DockWidgetArea']) -> None: ...
        @typing.overload
        def __init__(self, a0: 'ads.DockWidgetAreas') -> None: ...

        def __hash__(self) -> int: ...
        def __bool__(self) -> int: ...
        def __invert__(self) -> 'ads.DockWidgetAreas': ...
        def __int__(self) -> int: ...

    class CDockWidget(QtWidgets.QFrame):

        class eToggleViewActionMode(int): ...
        ActionModeToggle = ... # type: 'ads.CDockWidget.eToggleViewActionMode'
        ActionModeShow = ... # type: 'ads.CDockWidget.eToggleViewActionMode'

        class eMinimumSizeHintMode(int): ...
        MinimumSizeHintFromDockWidget = ... # type: 'ads.CDockWidget.eMinimumSizeHintMode'
        MinimumSizeHintFromContent = ... # type: 'ads.CDockWidget.eMinimumSizeHintMode'

        class eInsertMode(int): ...
        AutoScrollArea = ... # type: 'ads.CDockWidget.eInsertMode'
        ForceScrollArea = ... # type: 'ads.CDockWidget.eInsertMode'
        ForceNoScrollArea = ... # type: 'ads.CDockWidget.eInsertMode'

        class eState(int): ...
        StateHidden = ... # type: 'ads.CDockWidget.eState'
        StateDocked = ... # type: 'ads.CDockWidget.eState'
        StateFloating = ... # type: 'ads.CDockWidget.eState'

        class DockWidgetFeature(int): ...
        DockWidgetClosable = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        DockWidgetMovable = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        DockWidgetFloatable = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        DockWidgetDeleteOnClose = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        CustomCloseHandling = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        DockWidgetFocusable = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        DefaultDockWidgetFeatures = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        AllDockWidgetFeatures = ... # type: 'ads.CDockWidget.DockWidgetFeature'
        NoDockWidgetFeatures = ... # type: 'ads.CDockWidget.DockWidgetFeature'

        class DockWidgetFeatures(sip.simplewrapper):

            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, f: typing.Union['ads.CDockWidget.DockWidgetFeatures', 'ads.CDockWidget.DockWidgetFeature']) -> None: ...
            @typing.overload
            def __init__(self, a0: 'ads.CDockWidget.DockWidgetFeatures') -> None: ...

            def __hash__(self) -> int: ...
            def __bool__(self) -> int: ...
            def __invert__(self) -> 'ads.CDockWidget.DockWidgetFeatures': ...
            def __int__(self) -> int: ...

        def __init__(self, title: str, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def featuresChanged(self, features: typing.Union['ads.CDockWidget.DockWidgetFeatures', 'ads.CDockWidget.DockWidgetFeature']) -> None: ...
        def visibilityChanged(self, visible: bool) -> None: ...
        def closeRequested(self) -> None: ...
        def topLevelChanged(self, topLevel: bool) -> None: ...
        def titleChanged(self, Title: str) -> None: ...
        def closed(self) -> None: ...
        def viewToggled(self, Open: bool) -> None: ...
        def showNormal(self) -> None: ...
        def showFullScreen(self) -> None: ...
        def closeDockWidget(self) -> None: ...
        def deleteDockWidget(self) -> None: ...
        def setFloating(self) -> None: ...
        def raise(self) -> None: ...
        def setAsCurrentTab(self) -> None: ...
        def toggleView(self, Open: bool = ...) -> None: ...
        def event(self, e: QtCore.QEvent) -> bool: ...
        def isCurrentTab(self) -> bool: ...
        def isTabbed(self) -> bool: ...
        def isFullScreen(self) -> bool: ...
        def setTabToolTip(self, text: str) -> None: ...
        def titleBarActions(self) -> typing.List[QtWidgets.QAction]: ...
        def setTitleBarActions(self, actions: typing.Iterable[QtWidgets.QAction]) -> None: ...
        def toolBarIconSize(self, State: 'ads.CDockWidget.eState') -> QtCore.QSize: ...
        def setToolBarIconSize(self, IconSize: QtCore.QSize, State: 'ads.CDockWidget.eState') -> None: ...
        def toolBarStyle(self, State: 'ads.CDockWidget.eState') -> QtCore.Qt.ToolButtonStyle: ...
        def setToolBarStyle(self, Style: QtCore.Qt.ToolButtonStyle, State: 'ads.CDockWidget.eState') -> None: ...
        def setToolBar(self, ToolBar: QtWidgets.QToolBar) -> None: ...
        def createDefaultToolBar(self) -> QtWidgets.QToolBar: ...
        def toolBar(self) -> QtWidgets.QToolBar: ...
        def icon(self) -> QtGui.QIcon: ...
        def setIcon(self, Icon: QtGui.QIcon) -> None: ...
        def isCentralWidget(self) -> bool: ...
        def setMinimumSizeHintMode(self, Mode: 'ads.CDockWidget.eMinimumSizeHintMode') -> None: ...
        def setToggleViewActionMode(self, Mode: 'ads.CDockWidget.eToggleViewActionMode') -> None: ...
        def toggleViewAction(self) -> QtWidgets.QAction: ...
        def isClosed(self) -> bool: ...
        def isInFloatingContainer(self) -> bool: ...
        def isFloating(self) -> bool: ...
        def dockAreaWidget(self) -> 'ads.CDockAreaWidget': ...
        def dockContainer(self) -> 'ads.CDockContainerWidget': ...
        def dockManager(self) -> 'ads.CDockManager': ...
        def features(self) -> 'ads.CDockWidget.DockWidgetFeatures': ...
        def setFeature(self, flag: 'ads.CDockWidget.DockWidgetFeature', on: bool) -> None: ...
        def setFeatures(self, features: typing.Union['ads.CDockWidget.DockWidgetFeatures', 'ads.CDockWidget.DockWidgetFeature']) -> None: ...
        def tabWidget(self) -> 'ads.CDockWidgetTab': ...
        def widget(self) -> QtWidgets.QWidget: ...
        def takeWidget(self) -> QtWidgets.QWidget: ...
        def setWidget(self, widget: QtWidgets.QWidget, InsertMode: 'ads.CDockWidget.eInsertMode' = ...) -> None: ...
        def minimumSizeHint(self) -> QtCore.QSize: ...
        def closeDockWidgetInternal(self, ForceClose: bool = ...) -> bool: ...
        def toggleViewInternal(self, Open: bool) -> None: ...
        def setClosedState(self, Closed: bool) -> None: ...
        def emitTopLevelChanged(self, Floating: bool) -> None: ...
        @staticmethod
        def emitTopLevelEventForWidget(TopLevelDockWidget: 'ads.CDockWidget', Floating: bool) -> None: ...
        def flagAsUnassigned(self) -> None: ...
        def saveState(self, Stream: QtCore.QXmlStreamWriter) -> None: ...
        def setToggleViewActionChecked(self, Checked: bool) -> None: ...
        def setDockArea(self, DockArea: 'ads.CDockAreaWidget') -> None: ...
        def setDockManager(self, DockManager: 'ads.CDockManager') -> None: ...

    class CDockAreaTabBar(QtWidgets.QScrollArea):

        def __init__(self, parent: 'ads.CDockAreaWidget') -> None: ...

        def tabInserted(self, index: int) -> None: ...
        def removingTab(self, index: int) -> None: ...
        def tabMoved(self, from_: int, to: int) -> None: ...
        def tabOpened(self, index: int) -> None: ...
        def tabClosed(self, index: int) -> None: ...
        def tabCloseRequested(self, index: int) -> None: ...
        def tabBarClicked(self, index: int) -> None: ...
        def currentChanged(self, Index: int) -> None: ...
        def currentChanging(self, Index: int) -> None: ...
        def closeTab(self, Index: int) -> None: ...
        def setCurrentIndex(self, Index: int) -> None: ...
        def elidedChanged(self, elided: bool) -> None: ...
        def sizeHint(self) -> QtCore.QSize: ...
        def minimumSizeHint(self) -> QtCore.QSize: ...
        def isTabOpen(self, Index: int) -> bool: ...
        def eventFilter(self, watched: QtCore.QObject, event: QtCore.QEvent) -> bool: ...
        def tab(self, Index: int) -> 'ads.CDockWidgetTab': ...
        def currentTab(self) -> 'ads.CDockWidgetTab': ...
        def currentIndex(self) -> int: ...
        def count(self) -> int: ...
        def removeTab(self, Tab: 'ads.CDockWidgetTab') -> None: ...
        def insertTab(self, Index: int, Tab: 'ads.CDockWidgetTab') -> None: ...
        def wheelEvent(self, Event: QtGui.QWheelEvent) -> None: ...

    class CTitleBarButton(QtWidgets.QToolButton):

        def __init__(self, visible: bool = ..., parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def setVisible(self, visible: bool) -> None: ...
        def event(self, ev: QtCore.QEvent) -> bool: ...

    class CSpacerWidget(QtWidgets.QWidget):

        def __init__(self, Parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def minimumSizeHint(self) -> QtCore.QSize: ...
        def sizeHint(self) -> QtCore.QSize: ...

    class CDockAreaTitleBar(QtWidgets.QFrame):

        def __init__(self, parent: 'ads.CDockAreaWidget') -> None: ...

        def tabBarClicked(self, index: int) -> None: ...
        def indexOf(self, widget: QtWidgets.QWidget) -> int: ...
        def insertWidget(self, index: int, widget: QtWidgets.QWidget) -> None: ...
        def setVisible(self, Visible: bool) -> None: ...
        def updateDockWidgetActionsButtons(self) -> None: ...
        def button(self, which: 'ads.TitleBarButton') -> QtWidgets.QAbstractButton: ...
        def tabBar(self) -> 'ads.CDockAreaTabBar': ...
        def markTabsMenuOutdated(self) -> None: ...
        def contextMenuEvent(self, event: QtGui.QContextMenuEvent) -> None: ...
        def mouseDoubleClickEvent(self, event: QtGui.QMouseEvent) -> None: ...
        def mouseMoveEvent(self, ev: QtGui.QMouseEvent) -> None: ...
        def mouseReleaseEvent(self, ev: QtGui.QMouseEvent) -> None: ...
        def mousePressEvent(self, ev: QtGui.QMouseEvent) -> None: ...

    class CDockAreaWidget(QtWidgets.QFrame):

        class eDockAreaFlag(int): ...
        HideSingleWidgetTitleBar = ... # type: 'ads.CDockAreaWidget.eDockAreaFlag'
        DefaultFlags = ... # type: 'ads.CDockAreaWidget.eDockAreaFlag'

        class DockAreaFlags(sip.simplewrapper):

            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, f: typing.Union['ads.CDockAreaWidget.DockAreaFlags', 'ads.CDockAreaWidget.eDockAreaFlag']) -> None: ...
            @typing.overload
            def __init__(self, a0: 'ads.CDockAreaWidget.DockAreaFlags') -> None: ...

            def __hash__(self) -> int: ...
            def __bool__(self) -> int: ...
            def __invert__(self) -> 'ads.CDockAreaWidget.DockAreaFlags': ...
            def __int__(self) -> int: ...

        def __init__(self, DockManager: 'ads.CDockManager', parent: 'ads.CDockContainerWidget') -> None: ...

        def viewToggled(self, Open: bool) -> None: ...
        def currentChanged(self, index: int) -> None: ...
        def currentChanging(self, index: int) -> None: ...
        def tabBarClicked(self, index: int) -> None: ...
        def closeOtherAreas(self) -> None: ...
        def closeArea(self) -> None: ...
        def setCurrentIndex(self, index: int) -> None: ...
        def isCentralWidgetArea(self) -> bool: ...
        def setDockAreaFlag(self, Flag: 'ads.CDockAreaWidget.eDockAreaFlag', On: bool) -> None: ...
        def setDockAreaFlags(self, Flags: typing.Union['ads.CDockAreaWidget.DockAreaFlags', 'ads.CDockAreaWidget.eDockAreaFlag']) -> None: ...
        def dockAreaFlags(self) -> 'ads.CDockAreaWidget.DockAreaFlags': ...
        def titleBar(self) -> 'ads.CDockAreaTitleBar': ...
        def allowedAreas(self) -> 'ads.DockWidgetAreas': ...
        def setAllowedAreas(self, areas: typing.Union['ads.DockWidgetAreas', 'ads.DockWidgetArea']) -> None: ...
        def setVisible(self, Visible: bool) -> None: ...
        def titleBarButton(self, which: 'ads.TitleBarButton') -> QtWidgets.QAbstractButton: ...
        def features(self, Mode: 'ads.eBitwiseOperator' = ...) -> 'ads.CDockWidget.DockWidgetFeatures': ...
        def saveState(self, Stream: QtCore.QXmlStreamWriter) -> None: ...
        def setCurrentDockWidget(self, DockWidget: 'ads.CDockWidget') -> None: ...
        def currentDockWidget(self) -> 'ads.CDockWidget': ...
        def indexOfFirstOpenDockWidget(self) -> int: ...
        def currentIndex(self) -> int: ...
        def dockWidget(self, Index: int) -> 'ads.CDockWidget': ...
        def openedDockWidgets(self) -> typing.List['ads.CDockWidget']: ...
        def openDockWidgetsCount(self) -> int: ...
        def dockWidgets(self) -> typing.List['ads.CDockWidget']: ...
        def dockWidgetsCount(self) -> int: ...
        def contentAreaGeometry(self) -> QtCore.QRect: ...
        def titleBarGeometry(self) -> QtCore.QRect: ...
        def minimumSizeHint(self) -> QtCore.QSize: ...
        def dockContainer(self) -> 'ads.CDockContainerWidget': ...
        def dockManager(self) -> 'ads.CDockManager': ...
        def toggleView(self, Open: bool) -> None: ...
        def markTitleBarMenuOutdated(self) -> None: ...
        def internalSetCurrentDockWidget(self, DockWidget: 'ads.CDockWidget') -> None: ...
        def updateTitleBarVisibility(self) -> None: ...
        def hideAreaWithNoVisibleContent(self) -> None: ...
        def index(self, DockWidget: 'ads.CDockWidget') -> int: ...
        def nextOpenDockWidget(self, DockWidget: 'ads.CDockWidget') -> 'ads.CDockWidget': ...
        def toggleDockWidgetView(self, DockWidget: 'ads.CDockWidget', Open: bool) -> None: ...
        def removeDockWidget(self, DockWidget: 'ads.CDockWidget') -> None: ...
        def addDockWidget(self, DockWidget: 'ads.CDockWidget') -> None: ...
        def insertDockWidget(self, index: int, DockWidget: 'ads.CDockWidget', Activate: bool = ...) -> None: ...

    class CDockComponentsFactory(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'ads.CDockComponentsFactory') -> None: ...

        @staticmethod
        def resetDefaultFactory() -> None: ...
        @staticmethod
        def setFactory(Factory: 'ads.CDockComponentsFactory') -> None: ...
        @staticmethod
        def factory() -> 'ads.CDockComponentsFactory': ...
        def createDockAreaTitleBar(self, DockArea: 'ads.CDockAreaWidget') -> 'ads.CDockAreaTitleBar': ...
        def createDockAreaTabBar(self, DockArea: 'ads.CDockAreaWidget') -> 'ads.CDockAreaTabBar': ...
        def createDockWidgetTab(self, DockWidget: 'ads.CDockWidget') -> 'ads.CDockWidgetTab': ...

    class CDockContainerWidget(QtWidgets.QFrame):

        def __init__(self, DockManager: 'ads.CDockManager', parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def dockAreaViewToggled(self, DockArea: 'ads.CDockAreaWidget', Open: bool) -> None: ...
        def dockAreasRemoved(self) -> None: ...
        def dockAreasAdded(self) -> None: ...
        def closeOtherAreas(self, KeepOpenArea: 'ads.CDockAreaWidget') -> None: ...
        def floatingWidget(self) -> 'ads.CFloatingDockContainer': ...
        def features(self) -> 'ads.CDockWidget.DockWidgetFeatures': ...
        def dumpLayout(self) -> None: ...
        def isFloating(self) -> bool: ...
        def visibleDockAreaCount(self) -> int: ...
        def dockAreaCount(self) -> int: ...
        def hasTopLevelDockWidget(self) -> bool: ...
        def openedDockAreas(self) -> typing.List['ads.CDockAreaWidget']: ...
        def dockArea(self, Index: int) -> 'ads.CDockAreaWidget': ...
        def dockAreaAt(self, GlobalPos: QtCore.QPoint) -> 'ads.CDockAreaWidget': ...
        def isInFrontOf(self, Other: 'ads.CDockContainerWidget') -> bool: ...
        def zOrderIndex(self) -> int: ...
        def removeDockWidget(self, Dockwidget: 'ads.CDockWidget') -> None: ...
        def addDockWidget(self, area: 'ads.DockWidgetArea', Dockwidget: 'ads.CDockWidget', DockAreaWidget: typing.Optional['ads.CDockAreaWidget'] = ...) -> 'ads.CDockAreaWidget': ...
        def updateSplitterHandles(self, splitter: QtWidgets.QSplitter) -> None: ...
        def dockWidgets(self) -> typing.List['ads.CDockWidget']: ...
        def topLevelDockArea(self) -> 'ads.CDockAreaWidget': ...
        def topLevelDockWidget(self) -> 'ads.CDockWidget': ...
        def lastAddedDockAreaWidget(self, area: 'ads.DockWidgetArea') -> 'ads.CDockAreaWidget': ...
        def restoreState(self, Stream: 'ads.CDockingStateReader', Testing: bool) -> bool: ...
        def saveState(self, Stream: QtCore.QXmlStreamWriter) -> None: ...
        def removeDockArea(self, area: 'ads.CDockAreaWidget') -> None: ...
        def addDockArea(self, DockAreaWidget: 'ads.CDockAreaWidget', area: 'ads.DockWidgetArea' = ...) -> None: ...
        def dropWidget(self, Widget: QtWidgets.QWidget, DropArea: 'ads.DockWidgetArea', TargetAreaWidget: 'ads.CDockAreaWidget') -> None: ...
        def dropFloatingWidget(self, FloatingWidget: 'ads.CFloatingDockContainer', TargetPos: QtCore.QPoint) -> None: ...
        def createRootSplitter(self) -> None: ...
        def rootSplitter(self) -> QtWidgets.QSplitter: ...
        def event(self, e: QtCore.QEvent) -> bool: ...

    class CDockingStateReader(QtCore.QXmlStreamReader):

        def __init__(self) -> None: ...

        def fileVersion(self) -> int: ...
        def setFileVersion(self, FileVersion: int) -> None: ...

    class CDockFocusController(QtCore.QObject):

        def __init__(self, DockManager: 'ads.CDockManager') -> None: ...

        def setDockWidgetFocused(self, focusedNow: 'ads.CDockWidget') -> None: ...
        def notifyFloatingWidgetDrop(self, FloatingWidget: 'ads.CFloatingDockContainer') -> None: ...
        def notifyWidgetOrAreaRelocation(self, RelocatedWidget: QtWidgets.QWidget) -> None: ...

    class CDockManager('ads.CDockContainerWidget'):

        class eConfigFlag(int): ...
        ActiveTabHasCloseButton = ... # type: 'ads.CDockManager.eConfigFlag'
        DockAreaHasCloseButton = ... # type: 'ads.CDockManager.eConfigFlag'
        DockAreaCloseButtonClosesTab = ... # type: 'ads.CDockManager.eConfigFlag'
        OpaqueSplitterResize = ... # type: 'ads.CDockManager.eConfigFlag'
        XmlAutoFormattingEnabled = ... # type: 'ads.CDockManager.eConfigFlag'
        XmlCompressionEnabled = ... # type: 'ads.CDockManager.eConfigFlag'
        TabCloseButtonIsToolButton = ... # type: 'ads.CDockManager.eConfigFlag'
        AllTabsHaveCloseButton = ... # type: 'ads.CDockManager.eConfigFlag'
        RetainTabSizeWhenCloseButtonHidden = ... # type: 'ads.CDockManager.eConfigFlag'
        OpaqueUndocking = ... # type: 'ads.CDockManager.eConfigFlag'
        DragPreviewIsDynamic = ... # type: 'ads.CDockManager.eConfigFlag'
        DragPreviewShowsContentPixmap = ... # type: 'ads.CDockManager.eConfigFlag'
        DragPreviewHasWindowFrame = ... # type: 'ads.CDockManager.eConfigFlag'
        AlwaysShowTabs = ... # type: 'ads.CDockManager.eConfigFlag'
        DockAreaHasUndockButton = ... # type: 'ads.CDockManager.eConfigFlag'
        DockAreaHasTabsMenuButton = ... # type: 'ads.CDockManager.eConfigFlag'
        DockAreaHideDisabledButtons = ... # type: 'ads.CDockManager.eConfigFlag'
        DockAreaDynamicTabsMenuButtonVisibility = ... # type: 'ads.CDockManager.eConfigFlag'
        FloatingContainerHasWidgetTitle = ... # type: 'ads.CDockManager.eConfigFlag'
        FloatingContainerHasWidgetIcon = ... # type: 'ads.CDockManager.eConfigFlag'
        HideSingleCentralWidgetTitleBar = ... # type: 'ads.CDockManager.eConfigFlag'
        FocusHighlighting = ... # type: 'ads.CDockManager.eConfigFlag'
        EqualSplitOnInsertion = ... # type: 'ads.CDockManager.eConfigFlag'
        FloatingContainerForceNativeTitleBar = ... # type: 'ads.CDockManager.eConfigFlag'
        FloatingContainerForceQWidgetTitleBar = ... # type: 'ads.CDockManager.eConfigFlag'
        DefaultDockAreaButtons = ... # type: 'ads.CDockManager.eConfigFlag'
        DefaultBaseConfig = ... # type: 'ads.CDockManager.eConfigFlag'
        DefaultOpaqueConfig = ... # type: 'ads.CDockManager.eConfigFlag'
        DefaultNonOpaqueConfig = ... # type: 'ads.CDockManager.eConfigFlag'
        NonOpaqueWithWindowFrame = ... # type: 'ads.CDockManager.eConfigFlag'

        class eViewMenuInsertionOrder(int): ...
        MenuSortedByInsertion = ... # type: 'ads.CDockManager.eViewMenuInsertionOrder'
        MenuAlphabeticallySorted = ... # type: 'ads.CDockManager.eViewMenuInsertionOrder'

        class ConfigFlags(sip.simplewrapper):

            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, f: typing.Union['ads.CDockManager.ConfigFlags', 'ads.CDockManager.eConfigFlag']) -> None: ...
            @typing.overload
            def __init__(self, a0: 'ads.CDockManager.ConfigFlags') -> None: ...

            def __hash__(self) -> int: ...
            def __bool__(self) -> int: ...
            def __invert__(self) -> 'ads.CDockManager.ConfigFlags': ...
            def __int__(self) -> int: ...

        def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def focusedDockWidgetChanged(self, a0: 'ads.CDockWidget', a1: 'ads.CDockWidget') -> None: ...
        def dockWidgetRemoved(self, a0: 'ads.CDockWidget') -> None: ...
        def dockWidgetAboutToBeRemoved(self, a0: 'ads.CDockWidget') -> None: ...
        def dockAreaCreated(self, a0: 'ads.CDockAreaWidget') -> None: ...
        def floatingWidgetCreated(self, a0: 'ads.CFloatingDockContainer') -> None: ...
        def perspectiveOpened(self, PerspectiveName: str) -> None: ...
        def openingPerspective(self, PerspectiveName: str) -> None: ...
        def stateRestored(self) -> None: ...
        def restoringState(self) -> None: ...
        def perspectivesRemoved(self) -> None: ...
        def perspectiveListChanged(self) -> None: ...
        def setDockWidgetFocused(self, DockWidget: 'ads.CDockWidget') -> None: ...
        def openPerspective(self, PerspectiveName: str) -> None: ...
        @staticmethod
        def startDragDistance() -> int: ...
        def isRestoringState(self) -> bool: ...
        def setViewMenuInsertionOrder(self, Order: 'ads.CDockManager.eViewMenuInsertionOrder') -> None: ...
        def viewMenu(self) -> QtWidgets.QMenu: ...
        def addToggleViewActionToMenu(self, ToggleViewAction: QtWidgets.QAction, Group: str = ..., GroupIcon: QtGui.QIcon = ...) -> QtWidgets.QAction: ...
        def setCentralWidget(self, widget: 'ads.CDockWidget') -> 'ads.CDockAreaWidget': ...
        def centralWidget(self) -> 'ads.CDockWidget': ...
        def loadPerspectives(self, Settings: QtCore.QSettings) -> None: ...
        def savePerspectives(self, Settings: QtCore.QSettings) -> None: ...
        def perspectiveNames(self) -> typing.List[str]: ...
        def removePerspectives(self, Names: typing.Iterable[str]) -> None: ...
        def removePerspective(self, Name: str) -> None: ...
        def addPerspective(self, UniquePrespectiveName: str) -> None: ...
        def restoreState(self, state: typing.Union[QtCore.QByteArray, bytes, bytearray], version: int = ...) -> bool: ...
        def saveState(self, version: int = ...) -> QtCore.QByteArray: ...
        def zOrderIndex(self) -> int: ...
        def floatingWidgets(self) -> typing.List['ads.CFloatingDockContainer']: ...
        def dockContainers(self) -> typing.List['ads.CDockContainerWidget']: ...
        def dockWidgetsMap(self) -> typing.Dict[str, CDockWidget*]: ...
        def removeDockWidget(self, Dockwidget: 'ads.CDockWidget') -> None: ...
        def findDockWidget(self, ObjectName: str) -> 'ads.CDockWidget': ...
        def addDockWidgetFloating(self, DockWidget: 'ads.CDockWidget') -> 'ads.CFloatingDockContainer': ...
        def addDockWidgetTabToArea(self, Dockwidget: 'ads.CDockWidget', DockAreaWidget: 'ads.CDockAreaWidget') -> 'ads.CDockAreaWidget': ...
        def addDockWidgetTab(self, area: 'ads.DockWidgetArea', Dockwidget: 'ads.CDockWidget') -> 'ads.CDockAreaWidget': ...
        def addDockWidget(self, area: 'ads.DockWidgetArea', Dockwidget: 'ads.CDockWidget', DockAreaWidget: typing.Optional['ads.CDockAreaWidget'] = ...) -> 'ads.CDockAreaWidget': ...
        @staticmethod
        def iconProvider() -> 'ads.CIconProvider': ...
        @staticmethod
        def testConfigFlag(Flag: 'ads.CDockManager.eConfigFlag') -> bool: ...
        @staticmethod
        def setConfigFlag(Flag: 'ads.CDockManager.eConfigFlag', On: bool = ...) -> None: ...
        @staticmethod
        def setConfigFlags(Flags: typing.Union['ads.CDockManager.ConfigFlags', 'ads.CDockManager.eConfigFlag']) -> None: ...
        @staticmethod
        def configFlags() -> 'ads.CDockManager.ConfigFlags': ...
        def showEvent(self, event: QtGui.QShowEvent) -> None: ...
        def notifyFloatingWidgetDrop(self, FloatingWidget: 'ads.CFloatingDockContainer') -> None: ...
        def notifyWidgetOrAreaRelocation(self, RelocatedWidget: QtWidgets.QWidget) -> None: ...
        def dockAreaOverlay(self) -> 'ads.CDockOverlay': ...
        def containerOverlay(self) -> 'ads.CDockOverlay': ...
        def removeDockContainer(self, DockContainer: 'ads.CDockContainerWidget') -> None: ...
        def registerDockContainer(self, DockContainer: 'ads.CDockContainerWidget') -> None: ...
        def removeFloatingWidget(self, FloatingWidget: 'ads.CFloatingDockContainer') -> None: ...
        def registerFloatingWidget(self, FloatingWidget: 'ads.CFloatingDockContainer') -> None: ...

    class CDockOverlay(QtWidgets.QFrame):

        class eMode(int): ...
        ModeDockAreaOverlay = ... # type: 'ads.CDockOverlay.eMode'
        ModeContainerOverlay = ... # type: 'ads.CDockOverlay.eMode'

        def __init__(self, parent: QtWidgets.QWidget, Mode: 'ads.CDockOverlay.eMode' = ...) -> None: ...

        def hideEvent(self, e: QtGui.QHideEvent) -> None: ...
        def showEvent(self, e: QtGui.QShowEvent) -> None: ...
        def paintEvent(self, e: QtGui.QPaintEvent) -> None: ...
        def event(self, e: QtCore.QEvent) -> bool: ...
        def dropOverlayRect(self) -> QtCore.QRect: ...
        def dropPreviewEnabled(self) -> bool: ...
        def enableDropPreview(self, Enable: bool) -> None: ...
        def hideOverlay(self) -> None: ...
        def showOverlay(self, target: QtWidgets.QWidget) -> 'ads.DockWidgetArea': ...
        def visibleDropAreaUnderCursor(self) -> 'ads.DockWidgetArea': ...
        def dropAreaUnderCursor(self) -> 'ads.DockWidgetArea': ...
        def allowedAreas(self) -> 'ads.DockWidgetAreas': ...
        def setAllowedAreas(self, areas: typing.Union['ads.DockWidgetAreas', 'ads.DockWidgetArea']) -> None: ...

    class CDockOverlayCross(QtWidgets.QWidget):

        class eIconColor(int): ...
        FrameColor = ... # type: 'ads.CDockOverlayCross.eIconColor'
        WindowBackgroundColor = ... # type: 'ads.CDockOverlayCross.eIconColor'
        OverlayColor = ... # type: 'ads.CDockOverlayCross.eIconColor'
        ArrowColor = ... # type: 'ads.CDockOverlayCross.eIconColor'
        ShadowColor = ... # type: 'ads.CDockOverlayCross.eIconColor'

        def __init__(self, overlay: 'ads.CDockOverlay') -> None: ...

        def setIconColors(self, Colors: str) -> None: ...
        def updatePosition(self) -> None: ...
        def reset(self) -> None: ...
        def updateOverlayIcons(self) -> None: ...
        def setupOverlayCross(self, Mode: 'ads.CDockOverlay.eMode') -> None: ...
        def cursorLocation(self) -> 'ads.DockWidgetArea': ...
        def setIconColor(self, ColorIndex: 'ads.CDockOverlayCross.eIconColor', Color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setAreaWidgets(self, widgets: typing.Dict['ads.DockWidgetArea', QtWidgets.QWidget]) -> None: ...
        def showEvent(self, e: QtGui.QShowEvent) -> None: ...
        def setIconShadowColor(self, Color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setIconArrowColor(self, Color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setIconOverlayColor(self, Color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setIconBackgroundColor(self, Color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        def setIconFrameColor(self, Color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor]) -> None: ...
        @typing.overload
        def iconColor(self) -> QtGui.QColor: ...
        @typing.overload
        def iconColor(self, ColorIndex: 'ads.CDockOverlayCross.eIconColor') -> QtGui.QColor: ...
        def iconColors(self) -> str: ...

    class CDockSplitter(QtWidgets.QSplitter):

        @typing.overload
        def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...
        @typing.overload
        def __init__(self, orientation: QtCore.Qt.Orientation, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def isResizingWithContainer(self) -> bool: ...
        def lastWidget(self) -> QtWidgets.QWidget: ...
        def firstWidget(self) -> QtWidgets.QWidget: ...
        def hasVisibleContent(self) -> bool: ...

    class CDockWidgetTab(QtWidgets.QFrame):

        def __init__(self, DockWidget: 'ads.CDockWidget', parent: typing.Optional[QtWidgets.QWidget] = ...) -> None: ...

        def elidedChanged(self, elided: bool) -> None: ...
        def moved(self, GlobalPos: QtCore.QPoint) -> None: ...
        def closeOtherTabsRequested(self) -> None: ...
        def closeRequested(self) -> None: ...
        def clicked(self) -> None: ...
        def activeTabChanged(self) -> None: ...
        def setVisible(self, visible: bool) -> None: ...
        def updateStyle(self) -> None: ...
        def setElideMode(self, mode: QtCore.Qt.TextElideMode) -> None: ...
        def event(self, e: QtCore.QEvent) -> bool: ...
        def isClosable(self) -> bool: ...
        def isTitleElided(self) -> bool: ...
        def setText(self, title: str) -> None: ...
        def text(self) -> str: ...
        def icon(self) -> QtGui.QIcon: ...
        def setIcon(self, Icon: QtGui.QIcon) -> None: ...
        def dockWidget(self) -> 'ads.CDockWidget': ...
        def dockAreaWidget(self) -> 'ads.CDockAreaWidget': ...
        def setDockAreaWidget(self, DockArea: 'ads.CDockAreaWidget') -> None: ...
        def setActiveTab(self, active: bool) -> None: ...
        def isActiveTab(self) -> bool: ...
        def mouseDoubleClickEvent(self, event: QtGui.QMouseEvent) -> None: ...
        def contextMenuEvent(self, ev: QtGui.QContextMenuEvent) -> None: ...
        def mouseMoveEvent(self, ev: QtGui.QMouseEvent) -> None: ...
        def mouseReleaseEvent(self, ev: QtGui.QMouseEvent) -> None: ...
        def mousePressEvent(self, ev: QtGui.QMouseEvent) -> None: ...

    class CElidingLabel(QtWidgets.QLabel):

        @typing.overload
        def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ..., f: typing.Union[QtCore.Qt.WindowFlags, QtCore.Qt.WindowType] = ...) -> None: ...
        @typing.overload
        def __init__(self, text: str, parent: typing.Optional[QtWidgets.QWidget] = ..., f: typing.Union[QtCore.Qt.WindowFlags, QtCore.Qt.WindowType] = ...) -> None: ...

        def elidedChanged(self, elided: bool) -> None: ...
        def doubleClicked(self) -> None: ...
        def clicked(self) -> None: ...
        def text(self) -> str: ...
        def setText(self, text: str) -> None: ...
        def sizeHint(self) -> QtCore.QSize: ...
        def minimumSizeHint(self) -> QtCore.QSize: ...
        def isElided(self) -> bool: ...
        def setElideMode(self, mode: QtCore.Qt.TextElideMode) -> None: ...
        def elideMode(self) -> QtCore.Qt.TextElideMode: ...
        def mouseDoubleClickEvent(self, ev: QtGui.QMouseEvent) -> None: ...
        def resizeEvent(self, event: QtGui.QResizeEvent) -> None: ...
        def mouseReleaseEvent(self, event: QtGui.QMouseEvent) -> None: ...

    class IFloatingWidget(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'ads.IFloatingWidget') -> None: ...

        def finishDragging(self) -> None: ...
        def moveFloating(self) -> None: ...
        def startFloating(self, DragStartMousePos: QtCore.QPoint, Size: QtCore.QSize, DragState: 'ads.eDragState', MouseEventHandler: QtWidgets.QWidget) -> None: ...

    class CFloatingDockContainer(QtWidgets.QWidget, 'ads.IFloatingWidget'):

        @typing.overload
        def __init__(self, DockManager: 'ads.CDockManager') -> None: ...
        @typing.overload
        def __init__(self, DockArea: 'ads.CDockAreaWidget') -> None: ...
        @typing.overload
        def __init__(self, DockWidget: 'ads.CDockWidget') -> None: ...

        def dockWidgets(self) -> typing.List['ads.CDockWidget']: ...
        def topLevelDockWidget(self) -> 'ads.CDockWidget': ...
        def hasTopLevelDockWidget(self) -> bool: ...
        def isClosable(self) -> bool: ...
        def dockContainer(self) -> 'ads.CDockContainerWidget': ...
        def nativeEvent(self, eventType: typing.Union[QtCore.QByteArray, bytes, bytearray], message: sip.voidptr) -> typing.Tuple[bool, int]: ...
        def showEvent(self, event: QtGui.QShowEvent) -> None: ...
        def hideEvent(self, event: QtGui.QHideEvent) -> None: ...
        def closeEvent(self, event: QtGui.QCloseEvent) -> None: ...
        def changeEvent(self, event: QtCore.QEvent) -> None: ...
        def updateWindowTitle(self) -> None: ...
        def restoreState(self, Stream: 'ads.CDockingStateReader', Testing: bool) -> bool: ...
        def moveFloating(self) -> None: ...
        def initFloatingGeometry(self, DragStartMousePos: QtCore.QPoint, Size: QtCore.QSize) -> None: ...
        def finishDragging(self) -> None: ...
        def startDragging(self, DragStartMousePos: QtCore.QPoint, Size: QtCore.QSize, MouseEventHandler: QtWidgets.QWidget) -> None: ...
        def startFloating(self, DragStartMousePos: QtCore.QPoint, Size: QtCore.QSize, DragState: 'ads.eDragState', MouseEventHandler: QtWidgets.QWidget) -> None: ...

    class CFloatingDragPreview(QtWidgets.QWidget, 'ads.IFloatingWidget'):

        @typing.overload
        def __init__(self, Content: QtWidgets.QWidget, parent: QtWidgets.QWidget) -> None: ...
        @typing.overload
        def __init__(self, Content: 'ads.CDockWidget') -> None: ...
        @typing.overload
        def __init__(self, Content: 'ads.CDockAreaWidget') -> None: ...

        def draggingCanceled(self) -> None: ...
        def finishDragging(self) -> None: ...
        def moveFloating(self) -> None: ...
        def startFloating(self, DragStartMousePos: QtCore.QPoint, Size: QtCore.QSize, DragState: 'ads.eDragState', MouseEventHandler: QtWidgets.QWidget) -> None: ...
        def eventFilter(self, watched: QtCore.QObject, event: QtCore.QEvent) -> bool: ...
        def paintEvent(self, e: QtGui.QPaintEvent) -> None: ...

    class CIconProvider(sip.simplewrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'ads.CIconProvider') -> None: ...

        def registerCustomIcon(self, IconId: 'ads.eIcon', icon: QtGui.QIcon) -> None: ...
        def customIcon(self, IconId: 'ads.eIcon') -> QtGui.QIcon: ...
